@@ -59,7 +59,8 @@ MainWindow::MainWindow(TranslationHandler* th, QSettings* settings) :
     mCStandardActions(new QActionGroup(this)),
     mCppStandardActions(new QActionGroup(this)),
     mSelectLanguageActions(new QActionGroup(this)),
-    mExiting(false)
+    mExiting(false),
+    mIsLogfileLoaded(false)
 {
     mUI.setupUi(this);
     mThread = new ThreadHandler(this);
@@ -221,8 +222,6 @@ void MainWindow::HandleCLIParams(const QStringList &params)
             LoadProjectFile(params[index + 1]);
     } else if ((index = params.indexOf(QRegExp(".*\\.cppcheck$", Qt::CaseInsensitive), 0)) >= 0 && index < params.length() && QFile(params[index]).exists()) {
         LoadProjectFile(params[index]);
-    } else if ((index = params.indexOf(QRegExp(".*\\.xml$", Qt::CaseInsensitive), 0)) >= 0 && index < params.length() && QFile(params[index]).exists()) {
-        LoadResults(params[index]);
     } else if (params.contains("-l")) {
         QString logFile;
         index = params.indexOf("-l");
@@ -239,6 +238,8 @@ void MainWindow::HandleCLIParams(const QStringList &params)
         } else {
             LoadResults(logFile);
         }
+    } else if ((index = params.indexOf(QRegExp(".*\\.xml$", Qt::CaseInsensitive), 0)) >= 0 && index < params.length() && QFile(params[index]).exists()) {
+        LoadResults(params[index],QDir::currentPath());
     } else
         DoCheckFiles(params);
 }
@@ -359,10 +360,14 @@ void MainWindow::DoCheckFiles(const QStringList &files)
     }
     ClearResults();
 
+    mIsLogfileLoaded = false;
     FileList pathList;
     pathList.AddPathList(files);
-    if (mProject)
+    if (mProject) {
         pathList.AddExcludeList(mProject->GetProjectFile()->GetExcludedPaths());
+    } else {
+        EnableProjectActions(false);
+    }
     QStringList fileNames = pathList.GetFileList();
 
     mUI.mResults->Clear(true);
@@ -729,7 +734,12 @@ void MainWindow::CheckDone()
     EnableCheckButtons(true);
     mUI.mActionSettings->setEnabled(true);
     mUI.mActionOpenXML->setEnabled(true);
-    EnableProjectActions(true);
+    if (mProject) {
+        EnableProjectActions(true);
+    } else if (mIsLogfileLoaded) {
+        mUI.mActionRecheckModified->setEnabled(false);
+        mUI.mActionRecheckAll->setEnabled(false);
+    }
     EnableProjectOpenActions(true);
     mPlatformActions->setEnabled(true);
     mCStandardActions->setEnabled(true);
@@ -753,7 +763,8 @@ void MainWindow::CheckDone()
 
     // Notify user - if the window is not active - that check is ready
     QApplication::alert(this, 3000);
-    ShowStatistics();
+    if (mSettings->value(SETTINGS_SHOW_STATISTICS, false).toBool())
+        ShowStatistics();
 }
 
 void MainWindow::CheckLockDownUI()
@@ -815,6 +826,7 @@ void MainWindow::ReCheckSelected(QStringList files, bool all)
     for (int i = 0; i < files.size(); ++i)
         mUI.mResults->ClearRecheckFile(files[i]);
 
+    mCurrentDirectory = mUI.mResults->GetCheckDirectory();
     FileList pathList;
     pathList.AddPathList(files);
     if (mProject)
@@ -899,7 +911,12 @@ void MainWindow::OpenResults()
 void MainWindow::LoadResults(const QString selectedFile)
 {
     if (!selectedFile.isEmpty()) {
+        if (mProject)
+            CloseProjectFile();
+        mIsLogfileLoaded = true;
         mUI.mResults->Clear(true);
+        mUI.mActionRecheckModified->setEnabled(false);
+        mUI.mActionRecheckAll->setEnabled(false);
         mUI.mResults->ReadErrorsXml(selectedFile);
         SetPath(SETTINGS_LAST_RESULT_PATH, selectedFile);
     }
@@ -1180,6 +1197,7 @@ void MainWindow::LoadProjectFile(const QString &filePath)
     FormatAndSetTitle(tr("Project:") + QString(" ") + filename);
     AddProjectMRU(filePath);
 
+    mIsLogfileLoaded = false;
     mUI.mActionCloseProjectFile->setEnabled(true);
     mUI.mActionEditProjectFile->setEnabled(true);
     delete mProject;
