@@ -28,6 +28,11 @@
 #include <limits>
 #include <stack>
 
+// CWE ids used
+static const struct CWE CWE398(398U);
+static const struct CWE CWE570(570U);
+static const struct CWE CWE571(571U);
+
 //---------------------------------------------------------------------------
 
 // Register this check class (by creating a static instance of it)
@@ -191,7 +196,7 @@ void CheckCondition::assignIfError(const Token *tok1, const Token *tok2, const s
     reportError(locations,
                 Severity::style,
                 "assignIfError",
-                "Mismatching assignment and comparison, comparison '" + condition + "' is always " + std::string(result ? "true" : "false") + ".");
+                "Mismatching assignment and comparison, comparison '" + condition + "' is always " + std::string(result ? "true" : "false") + ".", CWE398, false);
 }
 
 
@@ -208,7 +213,7 @@ void CheckCondition::mismatchingBitAndError(const Token *tok1, const MathLib::bi
     reportError(locations,
                 Severity::style,
                 "mismatchingBitAnd",
-                msg.str());
+                msg.str(), CWE398, false);
 }
 
 
@@ -256,8 +261,8 @@ void CheckCondition::checkBadBitmaskCheck()
                                    (parent->str() == "(" && Token::Match(parent->astOperand1(), "if|while")) ||
                                    (parent->str() == "return" && parent->astOperand1() == tok && inBooleanFunction(tok));
 
-            const bool isTrue = (tok->astOperand1()->values.size() == 1 && tok->astOperand1()->values.front().intvalue != 0 && !tok->astOperand1()->values.front().conditional) ||
-                                (tok->astOperand2()->values.size() == 1 && tok->astOperand2()->values.front().intvalue != 0 && !tok->astOperand2()->values.front().conditional);
+            const bool isTrue = (tok->astOperand1()->values.size() == 1 && tok->astOperand1()->values.front().intvalue != 0 && tok->astOperand1()->values.front().isKnown()) ||
+                                (tok->astOperand2()->values.size() == 1 && tok->astOperand2()->values.front().intvalue != 0 && tok->astOperand2()->values.front().isKnown());
 
             if (isBoolean && isTrue)
                 badBitmaskCheckError(tok);
@@ -317,7 +322,7 @@ void CheckCondition::comparisonError(const Token *tok, const std::string &bitop,
                              "spot sometimes. In case of complex expression it might help to split it to "
                              "separate expressions.");
 
-    reportError(tok, Severity::style, "comparisonError", errmsg);
+    reportError(tok, Severity::style, "comparisonError", errmsg, CWE398, false);
 }
 
 bool CheckCondition::isOverlappingCond(const Token * const cond1, const Token * const cond2, const std::set<std::string> &constFunctions) const
@@ -395,7 +400,7 @@ void CheckCondition::multiConditionError(const Token *tok, unsigned int line1)
     errmsg << "Expression is always false because 'else if' condition matches previous condition at line "
            << line1 << ".";
 
-    reportError(tok, Severity::style, "multiCondition", errmsg.str());
+    reportError(tok, Severity::style, "multiCondition", errmsg.str(), CWE398, false);
 }
 
 //---------------------------------------------------------------------------
@@ -481,7 +486,7 @@ void CheckCondition::oppositeInnerConditionError(const Token *tok1, const Token*
     std::list<const Token*> callstack;
     callstack.push_back(tok1);
     callstack.push_back(tok2);
-    reportError(callstack, Severity::warning, "oppositeInnerCondition", "Opposite conditions in nested 'if' blocks lead to a dead code block.");
+    reportError(callstack, Severity::warning, "oppositeInnerCondition", "Opposite conditions in nested 'if' blocks lead to a dead code block.", CWE398, false);
 }
 
 //---------------------------------------------------------------------------
@@ -805,17 +810,17 @@ void CheckCondition::incorrectLogicOperatorError(const Token *tok, const std::st
         reportError(tok, Severity::warning, "incorrectLogicOperator",
                     "Logical disjunction always evaluates to true: " + condition + ".\n"
                     "Logical disjunction always evaluates to true: " + condition + ". "
-                    "Are these conditions necessary? Did you intend to use && instead? Are the numbers correct? Are you comparing the correct variables?");
+                    "Are these conditions necessary? Did you intend to use && instead? Are the numbers correct? Are you comparing the correct variables?", CWE571, false);
     else
         reportError(tok, Severity::warning, "incorrectLogicOperator",
                     "Logical conjunction always evaluates to false: " + condition + ".\n"
                     "Logical conjunction always evaluates to false: " + condition + ". "
-                    "Are these conditions necessary? Did you intend to use || instead? Are the numbers correct? Are you comparing the correct variables?");
+                    "Are these conditions necessary? Did you intend to use || instead? Are the numbers correct? Are you comparing the correct variables?", CWE570, false);
 }
 
 void CheckCondition::redundantConditionError(const Token *tok, const std::string &text)
 {
-    reportError(tok, Severity::style, "redundantCondition", "Redundant condition: " + text);
+    reportError(tok, Severity::style, "redundantCondition", "Redundant condition: " + text, CWE398, false);
 }
 
 //-----------------------------------------------------------------------------
@@ -854,7 +859,7 @@ void CheckCondition::checkModuloAlwaysTrueFalse()
 void CheckCondition::moduloAlwaysTrueFalseError(const Token* tok, const std::string& maxVal)
 {
     reportError(tok, Severity::warning, "moduloAlwaysTrueFalse",
-                "Comparison of modulo result is predetermined, because it is always less than " + maxVal + ".");
+                "Comparison of modulo result is predetermined, because it is always less than " + maxVal + ".", CWE398, false);
 }
 
 //---------------------------------------------------------------------------
@@ -955,7 +960,7 @@ void CheckCondition::clarifyConditionError(const Token *tok, bool assign, bool b
     reportError(tok,
                 Severity::style,
                 "clarifyCondition",
-                errmsg);
+                errmsg, CWE398, false);
 }
 
 
@@ -981,6 +986,12 @@ void CheckCondition::alwaysTrueFalse()
             if (!tok->astParent() || !Token::Match(tok->astParent()->previous(), "%name% ("))
                 continue;
 
+            // Don't warn in assertions. Condition is often 'always true' by intention.
+            // If platform,defines,etc cause 'always false' then that is not dangerous neither.
+            const std::string &str = tok->astParent()->previous()->str();
+            if (str.find("assert")!=std::string::npos || str.find("ASSERT")!=std::string::npos)
+                continue;
+
             // Don't warn when there are expanded macros..
             bool isExpandedMacro = false;
             std::stack<const Token*> tokens;
