@@ -196,11 +196,17 @@ void Token::swapWithNext()
         std::swap(_flags, _next->_flags);
         std::swap(_varId, _next->_varId);
         std::swap(_fileIndex, _next->_fileIndex);
+        std::swap(_linenr, _next->_linenr);
+        if (_next->_link)
+            _next->_link->_link = this;
+        if (this->_link)
+            this->_link->_link = _next;
         std::swap(_link, _next->_link);
         std::swap(_scope, _next->_scope);
         std::swap(_function, _next->_function);
         std::swap(_originalName, _next->_originalName);
         std::swap(values, _next->values);
+        std::swap(valuetype, _next->valuetype);
         std::swap(_progressValue, _next->_progressValue);
     }
 }
@@ -225,6 +231,11 @@ void Token::deleteThis()
             _next->_originalName = nullptr;
         }
         values = _next->values;
+        if (_next->valuetype) {
+            delete valuetype;
+            valuetype = _next->valuetype;
+            _next->valuetype = nullptr;
+        }
         if (_link)
             _link->link(this);
 
@@ -247,6 +258,11 @@ void Token::deleteThis()
             _previous->_originalName = nullptr;
         }
         values = _previous->values;
+        if (_previous->valuetype) {
+            delete valuetype;
+            valuetype = _previous->valuetype;
+            _previous->valuetype = nullptr;
+        }
         if (_link)
             _link->link(this);
 
@@ -324,7 +340,7 @@ const std::string &Token::strAt(int index) const
     return tok ? tok->_str : emptyString;
 }
 
-static int multiComparePercent(const Token *tok, const char*& haystack, bool emptyStringFound, unsigned int varid)
+static int multiComparePercent(const Token *tok, const char*& haystack, unsigned int varid)
 {
     ++haystack;
     // Compare only the first character of the string for optimization reasons
@@ -458,8 +474,6 @@ static int multiComparePercent(const Token *tok, const char*& haystack, bool emp
 
     if (*haystack == '|')
         haystack += 1;
-    else if (*haystack == ' ' || *haystack == '\0')
-        return emptyStringFound ? 0 : -1;
     else
         return -1;
 
@@ -468,22 +482,17 @@ static int multiComparePercent(const Token *tok, const char*& haystack, bool emp
 
 int Token::multiCompare(const Token *tok, const char *haystack, unsigned int varid)
 {
-    bool emptyStringFound = false;
     const char *needle = tok->str().c_str();
     const char *needlePointer = needle;
     for (;;) {
         if (needlePointer == needle && haystack[0] == '%' && haystack[1] != '|' && haystack[1] != '\0' && haystack[1] != ' ') {
-            int ret = multiComparePercent(tok, haystack, emptyStringFound, varid);
+            int ret = multiComparePercent(tok, haystack, varid);
             if (ret < 2)
                 return ret;
         } else if (*haystack == '|') {
             if (*needlePointer == 0) {
                 // If needle is at the end, we have a match.
                 return 1;
-            } else if (needlePointer == needle) {
-                // If needlePointer was not increased at all, we had a empty
-                // string in the haystack
-                emptyStringFound = true;
             }
 
             needlePointer = needle;
@@ -508,7 +517,7 @@ int Token::multiCompare(const Token *tok, const char *haystack, unsigned int var
             } while (*haystack != ' ' && *haystack != '|' && *haystack);
 
             if (*haystack == ' ' || *haystack == '\0') {
-                return emptyStringFound ? 0 : -1;
+                return -1;
             }
 
             ++haystack;
@@ -518,10 +527,6 @@ int Token::multiCompare(const Token *tok, const char *haystack, unsigned int var
     if (*needlePointer == '\0')
         return 1;
 
-    // If empty string was found earlier from the haystack
-    if (emptyStringFound)
-        return 0;
-
     return -1;
 }
 
@@ -813,9 +818,11 @@ const Token * Token::findClosingBracket() const
                 closing = closing->link();
                 if (!closing)
                     return nullptr; // #6803
-            } else if (Token::Match(closing, "}|]|)|;"))
+            } else if (Token::Match(closing, "}|]|)|;")) {
+                if (depth > 0)
+                    return nullptr;
                 break;
-            else if (closing->str() == "<")
+            } else if (closing->str() == "<")
                 ++depth;
             else if (closing->str() == ">") {
                 if (--depth == 0)
