@@ -167,6 +167,7 @@ private:
         ASSERT_EQUALS(123, valueOfTok("x=123;",   "123").intvalue);
         ASSERT_EQUALS(0, valueOfTok("x=false;", "false").intvalue);
         ASSERT_EQUALS(1, valueOfTok("x=true;",  "true").intvalue);
+        ASSERT_EQUALS(0, valueOfTok("x(NULL);",  "NULL").intvalue);
         ASSERT_EQUALS((int)('a'), valueOfTok("x='a';",  "'a'").intvalue);
         ASSERT_EQUALS((int)('\n'), valueOfTok("x='\\n';", "'\\n'").intvalue);
     }
@@ -1065,6 +1066,15 @@ private:
                "}";
         ASSERT_EQUALS(false, testValueOfX(code, 3U, 87));
 
+        code = "void f() {\n"
+               "  int first=-1, x=0;\n"
+               "  do {\n"
+               "    if (first >= 0) { a = x; }\n" // <- x is not 0
+               "    first++; x=3;\n"
+               "  } while (1);\n"
+               "}";
+        ASSERT_EQUALS(false, testValueOfX(code, 4U, 0));
+
         // pointer/reference to x
         code = "int f(void) {\n"
                "  int x = 2;\n"
@@ -1166,6 +1176,14 @@ private:
                "  a = x;\n" // <- x can be 0
                "}\n";
         ASSERT_EQUALS(true, testValueOfX(code, 9U, 0)); // x can be 0 at line 9
+
+        code = "void f(const int a[]) {\n" // #6616
+               "  const int *x = 0;\n"
+               "  for (int i = 0; i < 10; i = *x) {\n" // <- x is not 0
+               "    x = a[i];\n"
+               "  }\n"
+               "}\n";
+        ASSERT_EQUALS(false, testValueOfX(code, 3U, 0));
     }
 
     void valueFlowAfterCondition() {
@@ -1222,6 +1240,12 @@ private:
                "}";
         ASSERT_EQUALS(false, testValueOfX(code, 3U, 0));
 
+        code = "void f(int x) {\n"
+               "    if (!x) { { throw new string(); }; }\n"
+               "    a = x;\n"
+               "}";
+        ASSERT_EQUALS(false, testValueOfX(code, 3U, 0));
+
         // if (var)
         code = "void f(int x) {\n"
                "    if (x) { a = x; }\n"  // <- x is not 0
@@ -1585,6 +1609,19 @@ private:
                "    n = (int)(i < 10 || abs(negWander) < abs(negTravel));\n"
                "}";
         testValueOfX(code,0,0); // <- dont hang
+
+        // conditional code in loop
+        code = "void f(int mask) {\n" // #6000
+               "  for (int x = 10; x < 14; x++) {\n"
+               "    int bit = mask & (1 << i);\n"
+               "    if (bit) {\n"
+               "      if (bit == (1 << 10)) {}\n"
+               "      else { a = x; }\n" // <- x is not 10
+               "    }\n"
+               "  }\n"
+               "}";
+        ASSERT_EQUALS(false, testValueOfX(code, 6U, 10));
+
     }
 
     void valueFlowSubFunction() {
@@ -1703,14 +1740,11 @@ private:
 
     bool isNotKnownValues(const char code[], const char str[]) {
         const std::list<ValueFlow::Value> values = tokenValues(code, str);
-        bool possible = false;
         for (std::list<ValueFlow::Value>::const_iterator it = values.begin(); it != values.end(); ++it) {
             if (it->isKnown())
                 return false;
-            if (it->isPossible())
-                possible = true;
         }
-        return possible;
+        return true;
     }
 
     void knownValue() {
@@ -1728,6 +1762,26 @@ private:
         ASSERT_EQUALS(3, value.intvalue);
         ASSERT(value.isKnown());
 
+        {
+            code = "void f() {\n"
+                   "  int x = 15;\n"
+                   "  if (x == 15) { x += 7; }\n" // <- condition is true
+                   "}";
+            value = valueOfTok(code, "==");
+            ASSERT_EQUALS(1, value.intvalue);
+            ASSERT(value.isKnown());
+
+            code = "int f() {\n"
+                   "    int a = 0, x = 0;\n"
+                   "    a = index();\n"
+                   "    if (a != 0)\n"
+                   "        x = next();\n"
+                   "    return x + 1;\n"
+                   "}\n";
+            value = valueOfTok(code, "+");
+            ASSERT(value.isPossible());
+        }
+
         code = "void f() {\n"
                "  int x;\n"
                "  if (ab) { x = 7; }\n"
@@ -1825,16 +1879,6 @@ private:
         ASSERT_EQUALS(1, value.intvalue);
         ASSERT(value.isPossible());
 
-        code = "void f() {\n"
-               "  int x = 0;\n"
-               "  do {\n"
-               "    if (!x) { x = y; }\n" // <- possible value
-               "  } while (count < 10);\n"
-               "}";
-        value = valueOfTok(code, "!");
-        ASSERT_EQUALS(1, value.intvalue);
-        ASSERT(value.isPossible());
-
         code = "void f() {\n"
                "  int x = 0;\n"
                "a:\n"
@@ -1853,6 +1897,20 @@ private:
         ASSERT_EQUALS(5, value.intvalue);
         ASSERT(value.isPossible());
 
+        code = "int f(int x) {\n"
+               "  if (x < 2) {}\n"
+               "  else if (x >= 2) {}\n" // <- known value
+               "}";
+        value = valueOfTok(code, ">=");
+        ASSERT_EQUALS(1, value.intvalue);
+        ASSERT(value.isKnown());
+
+        code = "int f(int x) {\n"
+               "  if (x < 2) {}\n"
+               "  else if (x > 2) {}\n" // <- possible value
+               "}";
+        ASSERT(isNotKnownValues(code, ">"));
+
         // function
         code = "int f(int x) { return x + 1; }\n" // <- possible value
                "void a() { f(12); }\b";
@@ -1868,6 +1926,12 @@ private:
                "}";
         ASSERT_EQUALS(true,  testValueOfX(code, 3U, 1)); // value of x can be 1
         ASSERT_EQUALS(false, testValueOfX(code, 3U, 2)); // value of x can't be 2
+
+        // calculation with known result
+        code = "int f(int x) { a = x & 0; }"; // <- & is 0
+        value = valueOfTok(code, "&");
+        ASSERT_EQUALS(0, value.intvalue);
+        ASSERT(value.isKnown());
     }
 };
 
